@@ -7,7 +7,7 @@ use Carp;
 use POSIX ();
 use Time::Local qw//;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 # copy from Plack::Middleware::AccessLog
 our %formats = (
@@ -198,7 +198,7 @@ Apache::LogFormat::Compiler - Compile a log format string to perl-code
 
 =head1 DESCRIPTION
 
-Compile a log format string to perl-code. For faster generating access_log line.
+Compile a log format string to perl-code. For faster generation of access_log lines.
 
 =head1 METHOD
 
@@ -236,7 +236,7 @@ with one of the mandatory modifier flags C<i>, C<o> or C<t>:
    %{header-name}o      header-name header in the response
    %{time-format]t      localtime in the specified strftime format
 
-=item log_line($env:HashRef,$res:ArrayRef,$length:Integer,$reqtime:Integer,$time:Integer): $log:String
+=item log_line($env:HashRef, $res:ArrayRef, $length:Integer, $reqtime:Integer, $time:Integer): $log:String
 
 Generates log line.
 
@@ -274,7 +274,7 @@ Sample psgi
 
 =head1 ADD CUSTOM FORMAT STRING
 
-Apache::LogFormat::Compiler allows to add custom format string
+Apache::LogFormat::Compiler allows one to add a custom format string
 
   my $log_handler = Apache::LogFormat::Compiler->new(
       '%z %{HTTP_X_FORWARDED_FOR|REMOTE_ADDR}Z',
@@ -294,10 +294,10 @@ Apache::LogFormat::Compiler allows to add custom format string
       },
   );
 
-Any single letter can be used other than Apache::LogFormat::Compiler used.
-Your sub is called with two or three arguments the content inside the C<{}> 
-from the format (block_handlers only), PSGI environment (C<$env>), 
-and ArrayRef of the response. It should return the string to be logged
+Any single letter can be used, other than those already defined by Apache::LogFormat::Compiler.
+Your sub is called with two or three arguments: the content inside the C<{}>
+from the format (block_handlers only), the PSGI environment (C<$env>),
+and the ArrayRef of the response. It should return the string to be logged.
 
 =head1 AUTHOR
 
